Learn R Programming

BigQuic (version 1.1-5)

BigQuic.select:

BigQuic Select

Description

Selects the optimal lambda value from those in the BigQuic_object, i.e. BigQuic Result.

Usage

BigQuic.select(BigQuic_result = NULL, stars.thresh = 0.1, stars.subsample.ratio = NULL, rep.num = 20, verbose = TRUE, verbose2 = 0)

Arguments

BigQuic_result
A BigQuic_object returned from running BigQuic.
stars.thresh
The threshold used in the Stars selection method for choosing a lambda
stars.subsample.ratio
The ratio giving how large the subsamples will be for Stars, if null there is a heuristic calculation.
rep.num
Number of times to do the repetition in Stars.
verbose
Controls the level of verbosity in a part of the code.
verbose2
Controls the level of verbosity in another section of code.